function [ret,x0,str,ts,xts]=scaomag2(t,x,u,flag);
%SCAOMAG2	is the M-file description of the SIMULINK system named SCAOMAG2.
%	SCAOMAG2 has a the following characteristics:
%		6 continuous states
%		0 discrete states
%		0 outputs
%		0 inputs
%		does not have direct feedthrough
%		1 sample times
%
%	The block-diagram can be displayed by typing: SCAOMAG2.
%
%	SYS=SCAOMAG2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAOMAG2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAOMAG2 with a FLAG of zero:
%	[SIZES]=SCAOMAG2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[223,55,994,580])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     'tsim')
set_param(sys,'Min step size', 'tsim/10000')
set_param(sys,'Max step size', 'tsim/2000')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/','Mc'])
set_param([sys,'/','Mc'],...
		'position',[335,225,340,230])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'position',[390,90,410,110])


%     Subsystem  ['Variables',13,'de commande1'].

new_system([sys,'/',['Variables',13,'de commande1']])
set_param([sys,'/',['Variables',13,'de commande1']],'Location',[4,50,527,265])

add_block('built-in/Inport',[sys,'/',['Variables',13,'de commande1/in_1']])
set_param([sys,'/',['Variables',13,'de commande1/in_1']],...
		'position',[15,105,35,125])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande1/To Workspace']])
set_param([sys,'/',['Variables',13,'de commande1/To Workspace']],...
		'hide name',0,...
		'mat-name','mx',...
		'buffer','points_trace',...
		'position',[170,76,250,94])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande1/To Workspace1']])
set_param([sys,'/',['Variables',13,'de commande1/To Workspace1']],...
		'hide name',0,...
		'mat-name','my',...
		'buffer','points_trace',...
		'position',[170,106,250,124])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande1/To Workspace2']])
set_param([sys,'/',['Variables',13,'de commande1/To Workspace2']],...
		'hide name',0,...
		'mat-name','mz',...
		'buffer','points_trace',...
		'position',[170,136,250,154])

add_block('built-in/Demux',[sys,'/',['Variables',13,'de commande1/Demux']])
set_param([sys,'/',['Variables',13,'de commande1/Demux']],...
		'hide name',0,...
		'outputs','3',...
		'position',[65,67,105,163])

add_block('built-in/Note',[sys,'/',['Variables',13,'de commande1/COUPLES DE COMMANDE PAR MAGNETOCOUPLEURS',13,' SUR LES AXES SATELLITE']])
set_param([sys,'/',['Variables',13,'de commande1/COUPLES DE COMMANDE PAR MAGNETOCOUPLEURS',13,' SUR LES AXES SATELLITE']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['Variables',13,'de commande1/COUPLES DE COMMANDE PAR MAGNETOCOUPLEURS',13,' SUR LES AXES SATELLITE']],...
		'position',[270,15,275,20])
add_line([sys,'/',['Variables',13,'de commande1']],[110,145;165,145])
add_line([sys,'/',['Variables',13,'de commande1']],[110,115;165,115])
add_line([sys,'/',['Variables',13,'de commande1']],[110,85;165,85])
add_line([sys,'/',['Variables',13,'de commande1']],[40,115;60,115])
set_param([sys,'/',['Variables',13,'de commande1']],...
		'Mask Display','Commande\nmagnto-coupleurs')


%     Finished composite block ['Variables',13,'de commande1'].

set_param([sys,'/',['Variables',13,'de commande1']],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'position',[60,341,180,409])


%     Subsystem  ['Perturbations',13,'arodynamiques'].

new_system([sys,'/',['Perturbations',13,'arodynamiques']])
set_param([sys,'/',['Perturbations',13,'arodynamiques']],'Location',[4,50,307,218])
open_system([sys,'/',['Perturbations',13,'arodynamiques']])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant1']],...
		'hide name',0,...
		'Value','0',...
		'position',[40,55,85,75])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques/Mux']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Mux']],...
		'inputs','3',...
		'position',[170,48,205,142])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant2']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant2']],...
		'hide name',0,...
		'Value','2e-5',...
		'position',[40,85,85,105])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant3']],...
		'hide name',0,...
		'Value','0',...
		'position',[40,115,85,135])

add_block('built-in/Outport',[sys,'/',['Perturbations',13,'arodynamiques/out_1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/out_1']],...
		'position',[260,85,280,105])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[90,65;165,65])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[90,95;165,95])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[90,125;165,125])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[210,95;255,95])
set_param([sys,'/',['Perturbations',13,'arodynamiques']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['Perturbations',13,'arodynamiques'].

set_param([sys,'/',['Perturbations',13,'arodynamiques']],...
		'ForeGround',2,...
		'position',[65,85,165,135])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[485,92,535,108])


%     Subsystem  ['Variables',13,'de commande'].

new_system([sys,'/',['Variables',13,'de commande']])
set_param([sys,'/',['Variables',13,'de commande']],'Location',[4,50,348,269])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande/To Workspace2']])
set_param([sys,'/',['Variables',13,'de commande/To Workspace2']],...
		'hide name',0,...
		'mat-name','commande_z',...
		'buffer','points_trace',...
		'position',[135,131,215,149])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande/To Workspace1']])
set_param([sys,'/',['Variables',13,'de commande/To Workspace1']],...
		'hide name',0,...
		'mat-name','commande_y',...
		'buffer','points_trace',...
		'position',[135,101,215,119])

add_block('built-in/Demux',[sys,'/',['Variables',13,'de commande/Demux']])
set_param([sys,'/',['Variables',13,'de commande/Demux']],...
		'hide name',0,...
		'outputs','3',...
		'position',[65,62,105,158])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande/To Workspace']])
set_param([sys,'/',['Variables',13,'de commande/To Workspace']],...
		'hide name',0,...
		'mat-name','commande_x',...
		'buffer','points_trace',...
		'position',[135,71,215,89])

add_block('built-in/Inport',[sys,'/',['Variables',13,'de commande/in_1']])
set_param([sys,'/',['Variables',13,'de commande/in_1']],...
		'position',[15,105,35,125])
add_line([sys,'/',['Variables',13,'de commande']],[110,140;130,140])
add_line([sys,'/',['Variables',13,'de commande']],[110,110;130,110])
add_line([sys,'/',['Variables',13,'de commande']],[110,80;130,80])
add_line([sys,'/',['Variables',13,'de commande']],[40,115;60,110])
set_param([sys,'/',['Variables',13,'de commande']],...
		'Mask Display','Commande\nde couple\nsur les trois axes')


%     Finished composite block ['Variables',13,'de commande'].

set_param([sys,'/',['Variables',13,'de commande']],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'position',[580,119,705,181])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'position',[215,97,250,123])

add_block('built-in/Note',[sys,'/','Mp'])
set_param([sys,'/','Mp'],...
		'position',[285,85,290,90])

add_block('built-in/Note',[sys,'/','m'])
set_param([sys,'/','m'],...
		'position',[197,180,202,185])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'position',[365,199,380,241])

add_block('built-in/State-Space',[sys,'/','State-space'])
set_param([sys,'/','State-space'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'A','Asat',...
		'B','Bsat',...
		'C','eye(size(Asat))',...
		'D','zeros(size(Bsat))',...
		'X0','[0.1 0 0.1 0 0.1 0]''')
set_param([sys,'/','State-space'],...
		'Mask Display','MODELE\nSATELLITE',...
		'position',[400,193,515,247])


%     Subsystem  ['Calcul couples',13,'de commande'].

new_system([sys,'/',['Calcul couples',13,'de commande']])
set_param([sys,'/',['Calcul couples',13,'de commande']],'Location',[4,50,341,199])

add_block('built-in/Inport',[sys,'/',['Calcul couples',13,'de commande/in_1']])
set_param([sys,'/',['Calcul couples',13,'de commande/in_1']],...
		'position',[10,50,30,70])

add_block('built-in/Inport',[sys,'/',['Calcul couples',13,'de commande/in_2']])
set_param([sys,'/',['Calcul couples',13,'de commande/in_2']],...
		'Port','2',...
		'position',[10,85,30,105])

add_block('built-in/Outport',[sys,'/',['Calcul couples',13,'de commande/out_1']])
set_param([sys,'/',['Calcul couples',13,'de commande/out_1']],...
		'position',[260,70,280,90])

add_block('built-in/Mux',[sys,'/',['Calcul couples',13,'de commande/Mux']])
set_param([sys,'/',['Calcul couples',13,'de commande/Mux']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[90,40,130,115])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul couples',13,'de commande/MATLAB Fcn']])
set_param([sys,'/',['Calcul couples',13,'de commande/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','dpvnorm(u(1:3),u(4:6))',...
		'Output Width','3',...
		'position',[160,59,225,101])
add_line([sys,'/',['Calcul couples',13,'de commande']],[135,80;155,80])
add_line([sys,'/',['Calcul couples',13,'de commande']],[35,60;85,60])
add_line([sys,'/',['Calcul couples',13,'de commande']],[230,80;255,80])
add_line([sys,'/',['Calcul couples',13,'de commande']],[35,95;85,95])
set_param([sys,'/',['Calcul couples',13,'de commande']],...
		'Mask Display','Calcul\ndes couples\nde contrle Mc')


%     Finished composite block ['Calcul couples',13,'de commande'].

set_param([sys,'/',['Calcul couples',13,'de commande']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[215,203,315,252])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[155,186,180,239])


%     Subsystem  'UnNamed4'.

new_system([sys,'/','UnNamed4'])
set_param([sys,'/','UnNamed4'],'Location',[4,50,296,231])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant2'])
set_param([sys,'/','UnNamed4/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,85,85,105])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant3'])
set_param([sys,'/','UnNamed4/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,110,85,130])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant1'])
set_param([sys,'/','UnNamed4/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,60,85,80])

add_block('built-in/Mux',[sys,'/','UnNamed4/Mux'])
set_param([sys,'/','UnNamed4/Mux'],...
		'inputs','3',...
		'position',[175,57,205,133])

add_block('built-in/Outport',[sys,'/','UnNamed4/out_1'])
set_param([sys,'/','UnNamed4/out_1'],...
		'position',[255,85,275,105])
add_line([sys,'/','UnNamed4'],[90,70;170,70])
add_line([sys,'/','UnNamed4'],[90,95;170,95])
add_line([sys,'/','UnNamed4'],[90,120;170,120])
add_line([sys,'/','UnNamed4'],[210,95;250,95])
set_param([sys,'/','UnNamed4'],...
		'Mask Display','Consigne\nnulle')


%     Finished composite block 'UnNamed4'.

set_param([sys,'/','UnNamed4'],...
		'hide name',0,...
		'position',[65,180,125,220])

add_block('built-in/State-Space',[sys,'/',['Commande',13,'Proportionnelle-Drive']])
set_param([sys,'/',['Commande',13,'Proportionnelle-Drive']],...
		'orientation',2,...
		'ForeGround',3,...
		'BackGround',6,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','gain',...
		'Mask Display','Retour\nd''tat')
set_param([sys,'/',['Commande',13,'Proportionnelle-Drive']],...
		'Mask Dialogue','SAISIE DES GAINS|Rappel roulis (kpx)|Rappel vitesse roulis (kdx)|Rappel tangage (kpy)|Rappel vitesse tangage (kdy)|Rappel lacet (kpz)|Rappel vitesse lacet')
set_param([sys,'/',['Commande',13,'Proportionnelle-Drive']],...
		'Mask Translate','gain=[-@1 -@2 0 0 0 0;0 0 -@3 -@4 0 0;0 0 0 0 -@5 -@6]',...
		'Mask Entries','25\/25000\/14\/15000\/75\/50000\/',...
		'position',[320,348,400,402])


%     Subsystem  ['Calcul champ magntique',13,'terrestre'].

new_system([sys,'/',['Calcul champ magntique',13,'terrestre']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],'Location',[4,50,899,490])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1',...
		'position',[390,234,465,266])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1',...
		'position',[400,104,465,136])

add_block('built-in/State-Space',[sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.1']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','[eye(3) zeros(3)]',...
		'Mask Display','Extraction\ndes angles')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.1']],...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.1']],...
		'position',[100,154,170,186])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/in_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/in_1']],...
		'position',[10,100,30,120])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[105,50,110,55])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur',13,'d''tat']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur',13,'d''tat']],...
		'position',[68,125,73,130])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Angles']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Angles']],...
		'position',[239,145,244,150])

add_block('built-in/Mux',[sys,'/',['Calcul champ magntique',13,'terrestre/Mux2']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Mux2']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[340,344,370,391])

add_block('built-in/State-Space',[sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.3']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.3']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','Axe z',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.3']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.3']],...
		'Mask Entries','[0 -1 0 ;1 0 0 ;0 0 0]\/',...
		'position',[215,338,270,372])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn2']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn2']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1',...
		'position',[415,349,475,391])

add_block('built-in/Sum',[sys,'/',['Calcul champ magntique',13,'terrestre/Sum2']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Sum2']],...
		'hide name',0,...
		'position',[555,339,590,381])

add_block('built-in/Sum',[sys,'/',['Calcul champ magntique',13,'terrestre/Sum1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Sum1']],...
		'hide name',0,...
		'position',[555,220,570,260])

add_block('built-in/Mux',[sys,'/',['Calcul champ magntique',13,'terrestre/Mux1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[335,230,365,265])

add_block('built-in/State-Space',[sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.2']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.2']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','Axe y',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.2']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.2']],...
		'Mask Entries','[0 0 1;0 0 0;-1 0 0]\/',...
		'position',[215,223,270,257])

add_block('built-in/Sum',[sys,'/',['Calcul champ magntique',13,'terrestre/Sum']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Sum']],...
		'hide name',0,...
		'position',[555,95,575,130])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/BX']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/BX']],...
		'position',[540,75,545,80])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/BY']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/BY']],...
		'position',[530,205,535,210])

add_block('built-in/Mux',[sys,'/',['Calcul champ magntique',13,'terrestre/Mux3']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Mux3']],...
		'hide name',0,...
		'inputs','3',...
		'position',[620,220,665,260])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/By']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/By']],...
		'position',[584,215,589,220])

add_block('built-in/Mux',[sys,'/',['Calcul champ magntique',13,'terrestre/Mux']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Mux']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[335,100,365,135])

add_block('built-in/Demux',[sys,'/',['Calcul champ magntique',13,'terrestre/Demux']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Demux']],...
		'outputs','3',...
		'position',[320,44,380,76])

add_block('built-in/State-Space',[sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','Axe x',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.']],...
		'Mask Entries','[0 0 0;0 0 -1;0 1 0]\/',...
		'position',[215,93,270,127])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/in_2']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/in_2']],...
		'Port','2',...
		'position',[10,160,30,180])

add_block('built-in/Outport',[sys,'/',['Calcul champ magntique',13,'terrestre/out_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/out_1']],...
		'position',[765,230,785,250])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[710,170,715,175])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/BZ']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/BZ']],...
		'position',[515,325,520,330])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Bz']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Bz']],...
		'position',[604,290,609,295])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Bx']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Bx']],...
		'position',[604,170,609,175])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[595,360;595,255;615,255])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[580,115;595,115;595,225;615,225])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[385,50;520,50;520,105;550,105])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[385,60;505,60;505,230;550,230])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[385,70;490,70;490,350;550,350])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[35,110;210,110])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[180,110;180,60;315,60])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[575,240;615,240])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[180,110;180,355;210,355])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[180,240;210,240])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[175,170;310,170;310,125;330,125])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[310,170;310,380;335,380])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[310,255;330,255])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[480,370;550,370])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[275,355;335,355])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[375,370;410,370])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[370,250;385,250])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[275,240;330,240])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[470,250;550,250])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[470,120;550,120])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[275,110;330,110])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[370,120;395,120])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[35,170;95,170])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[670,240;760,240])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['Calcul champ magntique',13,'terrestre'].

set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'position',[270,270,405,325])

add_block('built-in/Note',[sys,'/','B'])
set_param([sys,'/','B'],...
		'position',[236,275,241,280])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[4,50,295,341])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'hide name',0,...
		'outputs','6',...
		'position',[65,32,115,218])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace'])
set_param([sys,'/','UnNamed1/To Workspace'],...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[195,43,265,57])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace1'])
set_param([sys,'/','UnNamed1/To Workspace1'],...
		'hide name',0,...
		'mat-name','v_roulis',...
		'buffer','points_trace',...
		'position',[195,73,270,87])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace2'])
set_param([sys,'/','UnNamed1/To Workspace2'],...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[190,101,265,119])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace3'])
set_param([sys,'/','UnNamed1/To Workspace3'],...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[190,131,265,149])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace4'])
set_param([sys,'/','UnNamed1/To Workspace4'],...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[190,163,270,177])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace5'])
set_param([sys,'/','UnNamed1/To Workspace5'],...
		'hide name',0,...
		'mat-name','v_lacet',...
		'buffer','points_trace',...
		'position',[195,193,275,207])

add_block('built-in/Inport',[sys,'/','UnNamed1/in_1'])
set_param([sys,'/','UnNamed1/in_1'],...
		'position',[15,115,35,135])

add_block('built-in/Note',[sys,'/',['UnNamed1/Sorties des variables',13,'angulaires et de leur drive']])
set_param([sys,'/',['UnNamed1/Sorties des variables',13,'angulaires et de leur drive']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[145,225,150,230])
add_line([sys,'/','UnNamed1'],[40,125;60,125])
add_line([sys,'/','UnNamed1'],[120,50;190,50])
add_line([sys,'/','UnNamed1'],[120,80;190,80])
add_line([sys,'/','UnNamed1'],[120,110;185,110])
add_line([sys,'/','UnNamed1'],[120,140;185,140])
add_line([sys,'/','UnNamed1'],[120,170;185,170])
add_line([sys,'/','UnNamed1'],[120,200;190,200])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','Sortie\nsystme\n(angles et\nvitesses angulaires)')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'position',[585,191,705,249])

add_block('built-in/From Workspace',[sys,'/','From Workspace'])
set_param([sys,'/','From Workspace'],...
		'orientation',2,...
		'hide name',0,...
		'matl_expr','[champ_magn_terr]',...
		'Mask Display','Champ magntique\nterrestre\n(repre orbital)',...
		'position',[585,261,710,309])

add_block('built-in/Note',[sys,'/',['MODELISATION D''UN SATELLITE SOUS GRADIENT DE GRAVITE',13,'AVEC LES OSCILLATIONS AMORTIES PAR MAGNETOCOUPLEURS']])
set_param([sys,'/',['MODELISATION D''UN SATELLITE SOUS GRADIENT DE GRAVITE',13,'AVEC LES OSCILLATIONS AMORTIES PAR MAGNETOCOUPLEURS']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',16,...
		'position',[405,10,410,15])


%     Subsystem  ['Double click',13,'on this for demo.1'].

new_system([sys,'/',['Double click',13,'on this for demo.1']])
set_param([sys,'/',['Double click',13,'on this for demo.1']],'Location',[-10,380,117,533])
set_param([sys,'/',['Double click',13,'on this for demo.1']],...
		'Mask Display','Modle avec ou sans perturbations)',...
		'Mask Dialogue',' ')


%     Finished composite block ['Double click',13,'on this for demo.1'].

set_param([sys,'/',['Double click',13,'on this for demo.1']],...
		'ForeGround',2,...
		'BackGround',5,...
		'hide name',0,...
		'position',[505,404,730,431])

add_block('built-in/Note',[sys,'/',['AVANT LA SIMULATION, INITIALISEZ  L E MODELE EN ',13,'LANCANT SCAODAT2.M DANS L''ESPACE MATLAB']])
set_param([sys,'/',['AVANT LA SIMULATION, INITIALISEZ  L E MODELE EN ',13,'LANCANT SCAODAT2.M DANS L''ESPACE MATLAB']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[390,465,395,470])
add_line(sys,[185,215;210,215])
add_line(sys,[130,200;150,200])
add_line(sys,[265,300;195,300;195,240;210,240])
add_line(sys,[580,285;410,285])
add_line(sys,[415,100;480,100])
add_line(sys,[170,110;210,110])
add_line(sys,[255,110;340,110;340,210;360,210])
add_line(sys,[385,220;395,220])
add_line(sys,[320,230;360,230])
add_line(sys,[330,230;330,150;575,150])
add_line(sys,[520,220;580,220])
add_line(sys,[530,220;530,375;405,375])
add_line(sys,[315,375;185,375])
add_line(sys,[210,375;210,315;140,315;150,225])
add_line(sys,[530,310;410,310])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
